Documentation
¶
Overview ¶
Package wire converts between domain types (pkg/job, internal/app) and the generated protobuf types.
All conversions are pure: they take values, return values, and never touch I/O. This keeps the gRPC adapters thin (just call ToProto / FromProto) and lets us unit-test the wire schema without spinning up a server.
Index ¶
- func BackoffFromProto(p *hearthv1.BackoffPolicy) job.BackoffPolicy
- func BackoffToProto(b job.BackoffPolicy) *hearthv1.BackoffPolicy
- func BlobRefFromProto(p *hearthv1.BlobRef) job.BlobRef
- func BlobRefToProto(r job.BlobRef) *hearthv1.BlobRef
- func BlobRefsFromProto(ps []*hearthv1.BlobRef) []job.BlobRef
- func BlobRefsToProto(rs []job.BlobRef) []*hearthv1.BlobRef
- func JobFromProto(p *hearthv1.Job) job.Job
- func JobToProto(j job.Job) *hearthv1.Job
- func LeaseFromProto(p *hearthv1.Lease) *job.Lease
- func LeaseToProto(l *job.Lease) *hearthv1.Lease
- func ProgressFromProto(p *hearthv1.Progress) *job.Progress
- func ProgressToProto(p *job.Progress) *hearthv1.Progress
- func ResultFromProto(p *hearthv1.Result) *job.Result
- func ResultToProto(r *job.Result) *hearthv1.Result
- func SpecFromProto(p *hearthv1.Spec) job.Spec
- func SpecToProto(s job.Spec) *hearthv1.Spec
- func StateFromProto(s hearthv1.State) job.State
- func StateToProto(s job.State) hearthv1.State
- func WorkerInfoFromProto(p *hearthv1.WorkerInfo) app.WorkerInfo
- func WorkerInfoToProto(w app.WorkerInfo) *hearthv1.WorkerInfo
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BackoffFromProto ¶
func BackoffFromProto(p *hearthv1.BackoffPolicy) job.BackoffPolicy
func BackoffToProto ¶
func BackoffToProto(b job.BackoffPolicy) *hearthv1.BackoffPolicy
func WorkerInfoFromProto ¶
func WorkerInfoFromProto(p *hearthv1.WorkerInfo) app.WorkerInfo
func WorkerInfoToProto ¶
func WorkerInfoToProto(w app.WorkerInfo) *hearthv1.WorkerInfo
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.